==> dianara_1.1.orig.tar.gz: dianara-v1.1/src/asactivity.h <==
/*
 *   This file is part of Dianara
 *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef ASACTIVITY_H
#define ASACTIVITY_H

#include <QObject>
#include <QVariantMap>
#include <QStringList>

#include <QDebug>


#include "asobject.h"
#include "mischelpers.h"


class ASActivity : public QObject
{
    Q_OBJECT

public:
    explicit ASActivity(QVariantMap activityMap,
                        QObject *parent = 0);
    ~ASActivity();

    ASObject *object();

    QString getId();
    QString getVerb();
    QString getGenerator();
    QString getCreatedAt();
    QString getUpdatedAt();
    QString getContent();
    QString getToString();
    QString getCCString();
    QStringList getRecipientsIdList();

    bool isShared();
    QString getSharedByName();
    QString getSharedById();
    QString getSharedByAvatar();

    QString getAuthorName();
    QString getAuthorId();
    QString getAuthorAvatar();
    QString getAuthorUrl();
    QString getAuthorHometown();
    QString getAuthorBio();


signals:

public slots:


private:
    ASObject *asObject;

    QString id;
    QString verb;
    QString generator;
    QString createdAt;
    QString updatedAt;
    QString content;

    QString toString;
    QString ccString;

    QStringList recipientsIdList;

    bool shared;
    QString sharedByName;
    QString sharedById;
    QString sharedByAvatar;

    QString authorName;
    QString authorId;
    QString authorAvatar;
    QString authorUrl;
    QString authorHometown;
    QString authorBio;
};

#endif // ASACTIVITY_H

==> dianara-v1.2.2.tar.gz: dianara-v1.2.2/src/asactivity.h <==
/*
 *   This file is part of Dianara
 *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef ASACTIVITY_H
#define ASACTIVITY_H

#include <QObject>
#include <QVariantMap>
#include <QStringList>

#include <QDebug>


#include "asobject.h"
#include "asperson.h"
#include "mischelpers.h"


class ASActivity : public QObject
{
    Q_OBJECT

public:
    explicit ASActivity(QVariantMap activityMap,
                        QObject *parent = 0);
    ~ASActivity();

    ASPerson *author();
    ASObject *object();
    ASObject *target();
    ASPerson *personObject();

    QString getId();
    QString getVerb();
    QString getGenerator();
    QString getCreatedAt();
    QString getUpdatedAt();
    QString getContent();

    QString getToString();
    QString getCCString();
    QStringList getRecipientsIdList();

    bool isShared();
    QString getSharedByName();
    QString getSharedById();
    QString getSharedByAvatar();

signals:

public slots:


private:
    ASPerson *asAuthor;
    ASObject *asObject;
    ASObject *asTarget;
    ASPerson *asPersonObject;

    QString id;
    QString verb;
    QString generator;
    QString createdAt;
    QString updatedAt;
    QString content;

    QString toString;
    QString ccString;

    QStringList recipientsIdList;

    bool shared;
    QString sharedByName;
    QString sharedById;
    QString sharedByAvatar;
};

#endif // ASACTIVITY_H
